@@ -4,14 +4,19 @@ use 5.008001;
 use Moose;
 
 # ABSTRACT: Special prereq handling
-our $VERSION = '1.85'; # VERSION
+our $VERSION = '1.86'; # VERSION
 
 
 with 'Dist::Zilla::Role::BeforeRelease';
 with 'Dist::Zilla::Role::PrereqSource';
 with 'Dist::Zilla::Role::InstallTool';
 
-sub mvp_multivalue_args { qw( upgrade ) }
+sub mvp_multivalue_args { qw( upgrade preamble ) }
+
+has preamble => (
+  is      => 'ro',
+  default => sub { [] },
+);
 
 has upgrade => (
   is      => 'ro',
@@ -113,7 +118,9 @@ sub setup_installer
   {
     my $content = $file->content;
     $content = join "\n", 
+      "use strict; use warnings;",
       "BEGIN {",
+      (map { s/^\| /  /; $_ } @{ $self->preamble }),
       "  unless(eval q{ use $perl_version; 1}) {",
       "    print \"Perl $perl_version or better required\\n\";",
       "    exit;",
@@ -140,7 +147,7 @@ Dist::Zilla::Plugin::Author::Plicease::SpecialPrereqs - Special prereq handling
 
 =head1 VERSION
 
-version 1.85
+version 1.86
 
 =head1 SYNOPSIS
 
