@@ -10,7 +10,7 @@ use Term::ANSIColor ();
 use Path::Class qw( file dir );
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.85'; # VERSION
+our $VERSION = '1.86'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -22,6 +22,7 @@ sub mvp_multivalue_args { qw(
   alien_bin_requires
   alien_helper
   upgrade
+  preamble
   
   diag
   allow_dirty ) }
@@ -188,7 +189,8 @@ sub configure
 
   $self->add_plugins([
     'Author::Plicease::SpecialPrereqs' => {
-      maybe upgrade => $self->payload->{upgrade},
+      maybe upgrade  => $self->payload->{upgrade},
+      maybe preamble => $self->payload->{preamble},
     },
   ]);
 
@@ -260,7 +262,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.85
+version 1.86
 
 =head1 SYNOPSIS
 
